# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from public_api_server_connector.models.response_wrapper_course_submodule import ResponseWrapperCourseSubmodule  # noqa: E501

class TestResponseWrapperCourseSubmodule(unittest.TestCase):
    """ResponseWrapperCourseSubmodule unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResponseWrapperCourseSubmodule:
        """Test ResponseWrapperCourseSubmodule
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResponseWrapperCourseSubmodule`
        """
        model = ResponseWrapperCourseSubmodule()  # noqa: E501
        if include_optional:
            return ResponseWrapperCourseSubmodule(
                done = True,
                result = public_api_server_connector.models.course_submodule.CourseSubmodule(
                    order = 56, 
                    title = '', 
                    is_published = True, 
                    id = 56, 
                    module_id = 56, 
                    created_at = 56, ),
                error = ''
            )
        else:
            return ResponseWrapperCourseSubmodule(
                done = True,
        )
        """

    def testResponseWrapperCourseSubmodule(self):
        """Test ResponseWrapperCourseSubmodule"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
